/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_tr extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ADP", "ADP" },
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARA", "ARA" },
            { "ARL", "ARL" },
            { "ARM", "ARM" },
            { "ARP", "ARP" },
            { "ARS", "ARS" },
            { "ATS", "ATS" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZM", "AZM" },
            { "AZN", "AZN" },
            { "BAD", "BAD" },
            { "BAM", "BAM" },
            { "BAN", "BAN" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BEC", "BEC" },
            { "BEF", "BEF" },
            { "BEL", "BEL" },
            { "BGL", "BGL" },
            { "BGM", "BGM" },
            { "BGN", "BGN" },
            { "BGO", "BGO" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BOL", "BOL" },
            { "BOP", "BOP" },
            { "BOV", "BOV" },
            { "BRB", "BRB" },
            { "BRC", "BRC" },
            { "BRE", "BRE" },
            { "BRN", "BRN" },
            { "BRR", "BRR" },
            { "BRZ", "BRZ" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BUK", "BUK" },
            { "BWP", "BWP" },
            { "BYB", "BYB" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHE", "CHE" },
            { "CHF", "CHF" },
            { "CHW", "CHW" },
            { "CLE", "CLE" },
            { "CLF", "CLF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "COU", "COU" },
            { "CRC", "CRC" },
            { "CSD", "CSD" },
            { "CSK", "CSK" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CYP", "CYP" },
            { "CZK", "CZK" },
            { "DDM", "DDM" },
            { "DEM", "DEM" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "ECS", "ECS" },
            { "ECV", "ECV" },
            { "EEK", "EEK" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESA", "ESA" },
            { "ESB", "ESB" },
            { "ESP", "ESP" },
            { "ETB", "ETB" },
            { "FIM", "FIM" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "FRF", "FRF" },
            { "GEK", "GEK" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GRD", "GRD" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRD", "HRD" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IEP", "IEP" },
            { "ILP", "ILP" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "ITL", "ITL" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRH", "KRH" },
            { "KRO", "KRO" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LTL", "LTL" },
            { "LTT", "LTT" },
            { "LUC", "LUC" },
            { "LUF", "LUF" },
            { "LUL", "LUL" },
            { "LVL", "LVL" },
            { "LVR", "LVR" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MCF", "MCF" },
            { "MDC", "MDC" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MKN", "MKN" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MTL", "MTL" },
            { "MTP", "MTP" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXP", "MXP" },
            { "MXV", "MXV" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIC", "NIC" },
            { "NIO", "NIO" },
            { "NLG", "NLG" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEI", "PEI" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PLZ", "PLZ" },
            { "PTE", "PTE" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "ROL", "ROL" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RUR", "RUR" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SIT", "SIT" },
            { "SKK", "SKK" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SRG", "SRG" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SUR", "SUR" },
            { "SVC", "SVC" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJR", "TJR" },
            { "TJS", "TJS" },
            { "TMM", "TMM" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TPE", "TPE" },
            { "TRL", "TRL" },
            { "TRY", "\u20ba" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UAK", "UAK" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "USN", "USN" },
            { "USS", "USS" },
            { "UYI", "UYI" },
            { "UYP", "UYP" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEB", "VEB" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VNN", "VNN" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XAG", "XAG" },
            { "XAU", "XAU" },
            { "XEU", "XEU" },
            { "XPT", "XPT" },
            { "XRE", "XRE" },
            { "XSU", "XSU" },
            { "XTS", "XTS" },
            { "XUA", "XUA" },
            { "YDD", "YDD" },
            { "YER", "YER" },
            { "YUD", "YUD" },
            { "YUM", "YUM" },
            { "YUN", "YUN" },
            { "YUR", "YUR" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "ZWR", "ZWR" },
            { "adp", "Andorra Pezetas\u0131" },
            { "aed", "Birle\u015fik Arap Emirlikleri Dirhemi" },
            { "afa", "Afganistan Afganisi (1927\u20132002)" },
            { "afn", "Afganistan Afganisi" },
            { "alk", "Arnavutluk Leki (1946\u20131965)" },
            { "all", "Arnavutluk Leki" },
            { "amd", "Ermenistan Dram\u0131" },
            { "ang", "Hollanda Antilleri Guldeni" },
            { "aoa", "Angola Kvanzas\u0131" },
            { "aok", "Angola Kvanzas\u0131 (1977\u20131990)" },
            { "aon", "Yeni Angola Kvanzas\u0131 (1990\u20132000)" },
            { "aor", "Angola Kvanzas\u0131 Reajustado (1995\u20131999)" },
            { "ara", "Arjantin Australi" },
            { "arl", "Arjantin Peso Leyi (1970\u20131983)" },
            { "arm", "Arjantin Pesosu (1881\u20131970)" },
            { "arp", "Arjantin Pezosu (1983\u20131985)" },
            { "ars", "Arjantin Pesosu" },
            { "ats", "Avusturya \u015eilini" },
            { "aud", "Avustralya Dolar\u0131" },
            { "awg", "Aruba Florini" },
            { "azm", "Azerbaycan Manat\u0131 (1993\u20132006)" },
            { "azn", "Azerbaycan Manat\u0131" },
            { "bad", "Bosna Hersek Dinar\u0131" },
            { "bam", "Konvertibl Bosna Hersek Mark\u0131" },
            { "ban", "Yeni Bosna Hersek Dinar\u0131 (1994\u20131997)" },
            { "bbd", "Barbados Dolar\u0131" },
            { "bdt", "Banglade\u015f Takas\u0131" },
            { "bec", "Bel\u00e7ika Frang\u0131 (konvertibl)" },
            { "bef", "Bel\u00e7ika Frang\u0131" },
            { "bel", "Bel\u00e7ika Frang\u0131 (finansal)" },
            { "bgl", "Bulgar Levas\u0131 (Hard)" },
            { "bgm", "Sosyalist Bulgaristan Levas\u0131" },
            { "bgn", "Bulgar Levas\u0131" },
            { "bgo", "Bulgar Levas\u0131 (1879\u20131952)" },
            { "bhd", "Bahreyn Dinar\u0131" },
            { "bif", "Burundi Frang\u0131" },
            { "bmd", "Bermuda Dolar\u0131" },
            { "bnd", "Brunei Dolar\u0131" },
            { "bob", "Bolivya Bolivyanosu" },
            { "bol", "Bolivya Bolivyanosu (1863\u20131963)" },
            { "bop", "Bolivya Pezosu" },
            { "bov", "Bolivya Mvdolu" },
            { "brb", "Yeni Brezilya Kruzeirosu (1967\u20131986)" },
            { "brc", "Brezilya Kruzadosu" },
            { "bre", "Brezilya Kruzeirosu (1990\u20131993)" },
            { "brl", "Brezilya Reali" },
            { "brn", "Yeni Brezilya Kruzadosu" },
            { "brr", "Brezilya Kruzeirosu" },
            { "brz", "Brezilya Kruzeirosu (1942\u20131967)" },
            { "bsd", "Bahama Dolar\u0131" },
            { "btn", "Butan Ngultrumu" },
            { "buk", "Burma Kyat\u0131" },
            { "bwp", "Botsvana Pulas\u0131" },
            { "byb", "Yeni Beyaz Rusya Rublesi (1994\u20131999)" },
            { "byn", "Belarus Rublesi" },
            { "byr", "Beyaz Rusya Rublesi (2000\u20132016)" },
            { "bzd", "Belize Dolar\u0131" },
            { "cad", "Kanada Dolar\u0131" },
            { "cdf", "Kongo Frang\u0131" },
            { "che", "WIR Avrosu" },
            { "chf", "\u0130svi\u00e7re Frang\u0131" },
            { "chw", "WIR Frang\u0131" },
            { "cle", "\u015eili Esk\u00fcdosu" },
            { "clf", "\u015eili Unidades de Fomento" },
            { "clp", "\u015eili Pesosu" },
            { "cnh", "\u00c7in Yuan\u0131 (offshore)" },
            { "cnx", "\u00c7in Halk Cumhuriyeti Merkez Bankas\u0131 Dolar\u0131" },
            { "cny", "\u00c7in Yuan\u0131" },
            { "cop", "Kolombiya Pesosu" },
            { "cou", "Unidad de Valor Real" },
            { "crc", "Kosta Rika Kolonu" },
            { "csd", "Eski S\u0131rbistan Dinar\u0131" },
            { "csk", "\u00c7ekoslavak Korunas\u0131 (Hard)" },
            { "cuc", "Konvertibl K\u00fcba Pesosu" },
            { "cup", "K\u00fcba Pesosu" },
            { "cve", "Cape Verde Esk\u00fcdosu" },
            { "cyp", "G\u00fcney K\u0131br\u0131s Liras\u0131" },
            { "czk", "\u00c7ek Korunas\u0131" },
            { "ddm", "Do\u011fu Alman Mark\u0131" },
            { "dem", "Alman Mark\u0131" },
            { "djf", "Cibuti Frang\u0131" },
            { "dkk", "Danimarka Kronu" },
            { "dop", "Dominik Pesosu" },
            { "dzd", "Cezayir Dinar\u0131" },
            { "ecs", "Ekvador Sukresi" },
            { "ecv", "Ekvador Unidad de Valor Constante (UVC)" },
            { "eek", "Estonya Krunu" },
            { "egp", "M\u0131s\u0131r Liras\u0131" },
            { "ern", "Eritre Nakfas\u0131" },
            { "esa", "\u0130spanyol Pezetas\u0131 (A hesab\u0131)" },
            { "esb", "\u0130spanyol Pezetas\u0131 (konvertibl hesap)" },
            { "esp", "\u0130spanyol Pezetas\u0131" },
            { "etb", "Etiyopya Birri" },
            { "eur", "Euro" },
            { "fim", "Fin Markkas\u0131" },
            { "fjd", "Fiji Dolar\u0131" },
            { "fkp", "Falkland Adalar\u0131 Liras\u0131" },
            { "frf", "Frans\u0131z Frang\u0131" },
            { "gbp", "\u0130ngiliz Sterlini" },
            { "gek", "G\u00fcrcistan Kupon Larisi" },
            { "gel", "G\u00fcrcistan Larisi" },
            { "ghc", "Gana Sedisi (1979\u20132007)" },
            { "ghs", "Gana Sedisi" },
            { "gip", "Cebelitar\u0131k Liras\u0131" },
            { "gmd", "Gambiya Dalasisi" },
            { "gnf", "Gine Frang\u0131" },
            { "gns", "Gine Sylisi" },
            { "gqe", "Ekvator Ginesi Ekuelesi" },
            { "grd", "Yunan Drahmisi" },
            { "gtq", "Guatemala Quetzal\u0131" },
            { "gwe", "Portekiz Ginesi Esk\u00fcdosu" },
            { "gwp", "Gine-Bissau Pezosu" },
            { "gyd", "Guyana Dolar\u0131" },
            { "hkd", "Hong Kong Dolar\u0131" },
            { "hnl", "Honduras Lempiras\u0131" },
            { "hrd", "H\u0131rvatistan Dinar\u0131" },
            { "hrk", "H\u0131rvatistan Kunas\u0131" },
            { "htg", "Haiti Gurdu" },
            { "huf", "Macar Forinti" },
            { "idr", "Endonezya Rupisi" },
            { "iep", "\u0130rlanda Liras\u0131" },
            { "ilp", "\u0130srail Liras\u0131" },
            { "ilr", "\u0130srail \u015eekeli (1980\u20131985)" },
            { "ils", "Yeni \u0130srail \u015eekeli" },
            { "inr", "Hindistan Rupisi" },
            { "iqd", "Irak Dinar\u0131" },
            { "irr", "\u0130ran Riyali" },
            { "isj", "\u0130zlanda Kronu (1918\u20131981)" },
            { "isk", "\u0130zlanda Kronu" },
            { "itl", "\u0130talyan Lireti" },
            { "jmd", "Jamaika Dolar\u0131" },
            { "jod", "\u00dcrd\u00fcn Dinar\u0131" },
            { "jpy", "Japon Yeni" },
            { "kes", "Kenya \u015eilini" },
            { "kgs", "K\u0131rg\u0131zistan Somu" },
            { "khr", "Kambo\u00e7ya Rieli" },
            { "kmf", "Komorlar Frang\u0131" },
            { "kpw", "Kuzey Kore Wonu" },
            { "krh", "G\u00fcney Kore Hwan\u0131 (1953\u20131962)" },
            { "kro", "G\u00fcney Kore Wonu (1945\u20131953)" },
            { "krw", "G\u00fcney Kore Wonu" },
            { "kwd", "Kuveyt Dinar\u0131" },
            { "kyd", "Cayman Adalar\u0131 Dolar\u0131" },
            { "kzt", "Kazakistan Tengesi" },
            { "lak", "Laos Kipi" },
            { "lbp", "L\u00fcbnan Liras\u0131" },
            { "lkr", "Sri Lanka Rupisi" },
            { "lrd", "Liberya Dolar\u0131" },
            { "lsl", "Lesotho Lotisi" },
            { "ltl", "Litvanya Litas\u0131" },
            { "ltt", "Litvanya Talonu" },
            { "luc", "Konvertibl L\u00fcksemburg Frang\u0131" },
            { "luf", "L\u00fcksemburg Frang\u0131" },
            { "lul", "Finansal L\u00fcksemburg Frang\u0131" },
            { "lvl", "Letonya Lat\u0131" },
            { "lvr", "Letonya Rublesi" },
            { "lyd", "Libya Dinar\u0131" },
            { "mad", "Fas Dirhemi" },
            { "maf", "Fas Frang\u0131" },
            { "mcf", "Monako Frang\u0131" },
            { "mdc", "Moldova Kuponu" },
            { "mdl", "Moldova Leyi" },
            { "mga", "Madagaskar Ariarisi" },
            { "mgf", "Madagaskar Frang\u0131" },
            { "mkd", "Makedonya Dinar\u0131" },
            { "mkn", "Makedonya Dinar\u0131 (1992\u20131993)" },
            { "mlf", "Mali Frang\u0131" },
            { "mmk", "Myanmar Kyat\u0131" },
            { "mnt", "Mo\u011folistan Tugriki" },
            { "mop", "Makao Patakas\u0131" },
            { "mro", "Moritanya Ugiyas\u0131 (1973\u20132017)" },
            { "mru", "Moritanya Ugiyas\u0131" },
            { "mtl", "Malta Liras\u0131" },
            { "mtp", "Malta Sterlini" },
            { "mur", "Mauritius Rupisi" },
            { "mvp", "Maldiv Rupisi" },
            { "mvr", "Maldiv Rufiyaas\u0131" },
            { "mwk", "Malavi Kva\u00e7as\u0131" },
            { "mxn", "Meksika Pesosu" },
            { "mxp", "G\u00fcm\u00fc\u015f Meksika Pezosu (1861\u20131992)" },
            { "mxv", "Meksika Unidad de Inversion (UDI)" },
            { "myr", "Malezya Ringgiti" },
            { "mze", "Mozambik Esk\u00fcdosu" },
            { "mzm", "Eski Mozambik Metikali" },
            { "mzn", "Mozambik Metikali" },
            { "nad", "Namibya Dolar\u0131" },
            { "ngn", "Nijerya Nairas\u0131" },
            { "nic", "Nikaragua Kordobas\u0131 (1988\u20131991)" },
            { "nio", "Nikaragua Kordobas\u0131" },
            { "nlg", "Hollanda Florini" },
            { "nok", "Norve\u00e7 Kronu" },
            { "npr", "Nepal Rupisi" },
            { "nzd", "Yeni Zelanda Dolar\u0131" },
            { "omr", "Umman Riyali" },
            { "pab", "Panama Balboas\u0131" },
            { "pei", "Peru \u0130nti" },
            { "pen", "Peru Sol\u00fc" },
            { "pes", "Peru Sol\u00fc (1863\u20131965)" },
            { "pgk", "Papua Yeni Gine Kinas\u0131" },
            { "php", "Filipinler Pesosu" },
            { "pkr", "Pakistan Rupisi" },
            { "pln", "Polonya Zlotisi" },
            { "plz", "Polonya Zlotisi (1950\u20131995)" },
            { "pte", "Portekiz Esk\u00fcdosu" },
            { "pyg", "Paraguay Guaranisi" },
            { "qar", "Katar Riyali" },
            { "rhd", "Rodezya Dolar\u0131" },
            { "rol", "Eski Romen Leyi" },
            { "ron", "Romen Leyi" },
            { "rsd", "S\u0131rp Dinar\u0131" },
            { "rub", "Rus Rublesi" },
            { "rur", "Rus Rublesi (1991\u20131998)" },
            { "rwf", "Ruanda Frang\u0131" },
            { "sar", "Suudi Arabistan Riyali" },
            { "sbd", "Solomon Adalar\u0131 Dolar\u0131" },
            { "scr", "Sey\u015feller Rupisi" },
            { "sdd", "Eski Sudan Dinar\u0131" },
            { "sdg", "Sudan Liras\u0131" },
            { "sdp", "Eski Sudan Liras\u0131" },
            { "sek", "\u0130sve\u00e7 Kronu" },
            { "sgd", "Singapur Dolar\u0131" },
            { "shp", "Saint Helena Liras\u0131" },
            { "sit", "Slovenya Tolar\u0131" },
            { "skk", "Slovak Korunas\u0131" },
            { "sll", "Sierra Leone Leonesi" },
            { "sos", "Somali \u015eilini" },
            { "srd", "Surinam Dolar\u0131" },
            { "srg", "Surinam Guldeni" },
            { "ssp", "G\u00fcney Sudan Liras\u0131" },
            { "std", "S\u00e3o Tom\u00e9 ve Pr\u00edncipe Dobras\u0131 (1977\u20132017)" },
            { "stn", "Sao Tome ve Principe Dobras\u0131" },
            { "sur", "Sovyet Rublesi" },
            { "svc", "El Salvador Kolonu" },
            { "syp", "Suriye Liras\u0131" },
            { "szl", "Svaziland Lilangenisi" },
            { "thb", "Tayland Baht\u0131" },
            { "tjr", "Tacikistan Rublesi" },
            { "tjs", "Tacikistan Somonisi" },
            { "tmm", "T\u00fcrkmenistan Manat\u0131 (1993\u20132009)" },
            { "tmt", "T\u00fcrkmenistan Manat\u0131" },
            { "tnd", "Tunus Dinar\u0131" },
            { "top", "Tonga Pa\u02bbangas\u0131" },
            { "tpe", "Timor Esk\u00fcdosu" },
            { "trl", "Eski T\u00fcrk Liras\u0131" },
            { "try", "T\u00fcrk Liras\u0131" },
            { "ttd", "Trinidad ve Tobago Dolar\u0131" },
            { "twd", "Yeni Tayvan Dolar\u0131" },
            { "tzs", "Tanzanya \u015eilini" },
            { "uah", "Ukrayna Grivnas\u0131" },
            { "uak", "Ukrayna Karbovanetz" },
            { "ugs", "Uganda \u015eilini (1966\u20131987)" },
            { "ugx", "Uganda \u015eilini" },
            { "usd", "ABD Dolar\u0131" },
            { "usn", "ABD Dolar\u0131 (Ertesi g\u00fcn)" },
            { "uss", "ABD Dolar\u0131 (Ayn\u0131 g\u00fcn)" },
            { "uyi", "Uruguay Peso en Unidades Indexadas" },
            { "uyp", "Uruguay Pezosu (1975\u20131993)" },
            { "uyu", "Uruguay Pesosu" },
            { "uzs", "\u00d6zbekistan Somu" },
            { "veb", "Venezuela Bolivar\u0131 (1871\u20132008)" },
            { "vef", "Venezuela Bolivar\u0131 (2008\u20132018)" },
            { "ves", "Venezuela Bolivar\u0131" },
            { "vnd", "Vietnam Dongu" },
            { "vnn", "Vietnam Dongu (1978\u20131985)" },
            { "vuv", "Vanuatu Vatusu" },
            { "wst", "Samoa Talas\u0131" },
            { "xaf", "Orta Afrika CFA Frang\u0131" },
            { "xag", "G\u00fcm\u00fc\u015f" },
            { "xau", "Alt\u0131n" },
            { "xba", "Birle\u015fik Avrupa Birimi" },
            { "xbb", "Avrupa Para Birimi (EMU)" },
            { "xbc", "Avrupa Hesap Birimi (XBC)" },
            { "xbd", "Avrupa Hesap Birimi (XBD)" },
            { "xcd", "Do\u011fu Karayip Dolar\u0131" },
            { "xdr", "\u00d6zel \u00c7ekme Hakk\u0131 (SDR)" },
            { "xeu", "Avrupa Para Birimi" },
            { "xfo", "Frans\u0131z Alt\u0131n Frang\u0131" },
            { "xfu", "Frans\u0131z UIC-Frang\u0131" },
            { "xof", "Bat\u0131 Afrika CFA Frang\u0131" },
            { "xpd", "Paladyum" },
            { "xpf", "CFP Frang\u0131" },
            { "xpt", "Platin" },
            { "xre", "RINET Fonlar\u0131" },
            { "xsu", "Sucre" },
            { "xts", "Test Para Birimi Kodu" },
            { "xua", "ADB Hesap Birimi" },
            { "xxx", "Bilinmeyen Para Birimi" },
            { "ydd", "Yemen Dinar\u0131" },
            { "yer", "Yemen Riyali" },
            { "yud", "Yugoslav Dinar\u0131 (Hard)" },
            { "yum", "Yeni Yugoslav Dinar\u0131" },
            { "yun", "Konvertibl Yugoslav Dinar\u0131" },
            { "yur", "\u0130yile\u015ftirilmi\u015f Yugoslav Dinar\u0131 (1992\u20131993)" },
            { "zal", "G\u00fcney Afrika Rand\u0131 (finansal)" },
            { "zar", "G\u00fcney Afrika Rand\u0131" },
            { "zmk", "Zambiya Kva\u00e7as\u0131 (1968\u20132012)" },
            { "zmw", "Zambiya Kva\u00e7as\u0131" },
            { "zrn", "Yeni Zaire Zairesi" },
            { "zrz", "Zaire Zairesi" },
            { "zwd", "Zimbabve Dolar\u0131" },
            { "zwl", "Zimbabve Dolar\u0131 (2009)" },
            { "zwr", "Zimbabve Dolar\u0131 (2008)" },
        };
        return data;
    }
}
